@@ -154,7 +154,11 @@ class StickProtocol():
         isInvitation = False
         if 'isInvitation' in data:
             isInvitation = data['isInvitation']
-        member = self.User.objects.get(id=memberId)
+        try:
+            member = self.User.objects.get(id=memberId)
+        except:
+            print('GETTING USING ONETIMEID')
+            member = self.User.objects.get(oneTimeId=memberId)
 
         # You need to check whether the user is authorized to fetch that SenderKey
         authorized = False
@@ -207,9 +211,8 @@ class StickProtocol():
         # through a realtime database.
         else:
             if not PendingKey.objects.filter(user=user, stickId=stickId).exists():
-                owner = self.User.objects.get(id=memberId)
-                PendingKey.objects.create(user=user, owner=owner, stickId=stickId)
-                phone = owner.phone
+                PendingKey.objects.create(user=user, owner=member, stickId=stickId)
+                phone = member.phone
         return {'authorized': authorized, 'senderKey': key, 'phone': phone}
 
     def get_standard_sender_keys(self, data, user, group):
